============
Installation
============

At the command line::

    $ easy_install porter2stemmer

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv porter2stemmer
    $ pip install porter2stemmer
